@@ -25,6 +25,7 @@
 #include <QTimer>
 #include <QVariantHash>
 #include <QStringList>
+#include <QWidget>
 
 #include <KUrl>
 
@@ -76,6 +77,7 @@
 #define KCUPS_JOB_PRINTER_URI            "job-printer-uri"
 #define KCUPS_JOB_PRINTER_STATE_MESSAGE  "job-printer-state-message"
 #define KCUPS_JOB_ORIGINATING_USER_NAME  "job-originating-user-name"
+#define KCUPS_JOB_ORIGINATING_HOST_NAME  "job-originating-host-name"
 #define KCUPS_JOB_MEDIA_PROGRESS         "job-media-progress"
 #define KCUPS_JOB_MEDIA_SHEETS           "job-media-sheets"
 #define KCUPS_JOB_MEDIA_SHEETS_COMPLETED "job-media-sheets-completed"
@@ -86,14 +88,30 @@
 #define KCUPS_JOB_SHEETS_DEFAULT         "job-sheets-default"
 #define KCUPS_JOB_SHEETS_SUPPORTED       "job-sheets-supported"
 
+#define KCUPS_MY_JOBS "my-jobs"
+#define KCUPS_WHICH_JOBS "which-jobs"
+
 #define KCUPS_TIME_AT_COMPLETED  "time-at-completed"
 #define KCUPS_TIME_AT_CREATION   "time-at-creation"
 #define KCUPS_TIME_AT_PROCESSING "time-at-processing"
 
+#define KCUPS_REQUESTED_ATTRIBUTES "requested-attributes"
+
+#define KCUPS_REQUESTING_USER_NAME         "requesting-user-name"
 #define KCUPS_REQUESTING_USER_NAME_ALLOWED "requesting-user-name-allowed"
 #define KCUPS_REQUESTING_USER_NAME_DENIED  "requesting-user-name-denied"
 
+#define KCUPS_PPD_MAKE_AND_MODEL "ppd-make-and-model"
+
+#define KCUPS_NOTIFY_EVENTS          "notify-events"
+#define KCUPS_NOTIFY_PULL_METHOD     "notify-pull-method"
+#define KCUPS_NOTIFY_RECIPIENT_URI   "notify-recipient-uri"
+#define KCUPS_NOTIFY_LEASE_DURATION  "notify-lease-duration"
+#define KCUPS_NOTIFY_SUBSCRIPTION_ID "notify-subscription-id"
+
 typedef QList<QVariantHash> ReturnArguments;
+
+class KIppRequest;
 class KCupsPasswordDialog;
 class KDE_EXPORT KCupsConnection : public QThread
 {
@@ -127,9 +145,11 @@ public:
      * on your own consider calling global()
      */
     explicit KCupsConnection(QObject *parent = 0);
-    KCupsConnection(const KUrl &server, QObject *parent = 0);
+    explicit KCupsConnection(const KUrl &server, QObject *parent = 0);
     ~KCupsConnection();
 
+    void setPasswordMainWindow(WId mainwindow);
+
 Q_SIGNALS:
     /**
      * emitted when "server-started" is registered
@@ -344,11 +364,8 @@ protected:
 
     virtual void run();
     bool readyToStart();
-    bool retry(const char *resource);
-    ReturnArguments request(ipp_op_e operation,
-                            const char *resource,
-                            const QVariantHash &reqValues,
-                            bool needResponse);
+    bool retry(const char *resource, int operation) const;
+    ReturnArguments request(const KIppRequest &request, ipp_tag_t groupTag = IPP_TAG_ZERO) const;
 
 private slots:
     void updateSubscription();
@@ -362,20 +379,14 @@ protected:
 
 private:
     void init();
-    /**
-     * This is the most weird cups function, the DBus API
-     * it is completely messy, and if we change the order of the attributes
-     * the call just fails. This is why we have a specific method
-     */
+
     int renewDBusSubscription(int subscriptionId, int leaseDuration, const QStringList &events = QStringList());
 
     void notifierConnect(const QString &signal, QObject *receiver, const char *slot);
 
-    static void requestAddValues(ipp_t *request, const QVariantHash &values);
     static ReturnArguments parseIPPVars(ipp_t *response,
-                                        int group_tag,
+                                        ipp_tag_t group_tag,
                                         bool needDestName);
-    static ipp_t* ippNewDefaultRequest(const QString &name, bool isClass, ipp_op_t operation);
     static QVariant ippAttrToVariant(ipp_attribute_t *attr);
 
     static KCupsConnection* m_instance;
